'use strict';

var units = require('./units.js');

/**
 * Generate CSS properties for absolute centering
 * @example
 *  jssAbsoluteCenter('3rem');
 *  // returns
 *  {
 *      top: '50%',
 *      left: '50%',
 *      width: '3rem',
 *      height: '3rem',
 *      margin: '-1.5rem 0 0 -1.5rem'
 *  }
 *
 *  jssAbsoluteCenter('4rem', '60px');
 *  // returns
 *  {
 *      top: '50%',
 *      left: '50%',
 *      width: '4rem',
 *      height: '60px',
 *      margin: '-30px 0 0 -2rem'
 *  }
 */
function absoluteCenter(width, height) {
	if (height === void 0) {
		height = width;
	}
	var mt = units.jssUnitLess(height) / 2 + units.jssUnitExtract(height);
	var ml = units.jssUnitLess(width) / 2 + units.jssUnitExtract(width);
	return {
		top: '50%',
		left: '50%',
		width: width,
		height: height,
		margin: '-' + mt + ' 0 0 -' + ml
	};
}

module.exports = absoluteCenter;
