'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

/**
 * Generate css math function `min(a, b)`
 * @example
 *  jssMin('5vw', '50px') // 'min(5vw, 50px)'
 *  jssMin('5vw', jssRem(64)) // 'min(5vw, 4rem)'
 */
var jssMin = function (a, b) {
	return 'min(' + a + ', ' + b + ')';
};
/**
 * Generate css math function `max(a, b)`
 * @example
 *  jssMax('5vw', '50px') // 'max(5vw, 50px)'
 *  jssMax('5vw', jssRem(64)) // 'max(5vw, 4rem)'
 */
var jssMax = function (a, b) {
	return 'max(' + a + ', ' + b + ')';
};
/**
 * Generate css math function `clap(min, val, max)`
 * @example
 *  jssClamp('10px', '5vw', '50px') // 'clamp(10px, 5vw, 50px)'
 *  jssClamp(jssRem(24), '10%', jssRem(64)) // 'clamp(1.5rem, 10%, 4rem)'
 */
var jssClamp = function (min, val, max) {
	return 'clamp(' + min + ', ' + val + ', ' + max + ')';
};
/**
 * Generate css math function-hack `max(x, min(y, z))` instead `clamp(z, y, x)`
 * @example
 *  jssClamp('10px', '5vw', '50px') // 'max(10px, min(5vw, 50px))'
 *  jssClamp(jssRem(24), '10%', jssRem(64)) // 'max(1.5rem, min(10%, 4rem))'
 */
var jssClampHack = function (min, val, max) {
	return 'max(' + min + ', min(' + val + ', ' + max + '))';
};

exports.jssClamp = jssClamp;
exports.jssClampHack = jssClampHack;
exports.jssMax = jssMax;
exports.jssMin = jssMin;
